@@ -8,12 +8,26 @@ use warnings;
 
 use parent ChemOnomatopist::Group::;
 
-sub is_carbon { return 1 }
+sub new
+{
+    my( $class, $ketone ) = @_;
+    return bless { ketone => $ketone }, $class;
+}
+
+sub element { return 'C' }
 
 sub is_part_of_chain() { return 1 }
 
 sub prefix { return 'formyl' }
-sub suffix { return 'al' }
+
+sub suffix()
+{
+    my( $self ) = @_;
+    my $name = $self->{ketone}->suffix;
+    $name =~ s/one$/al/;
+    return $name;
+}
+
 sub multisuffix { return 'carbaldehyde' }
 sub suffix_if_cycle_substituent { return 'carbaldehyde' }
 
