@@ -8,9 +8,9 @@ use warnings;
 
 use parent ChemOnomatopist::Group::;
 
+# FIXME: When part of chain, suffix is 'nitrile'; when an attachment - 'carbonitrile'.
+
 sub prefix { return 'cyano' }
 sub suffix { return 'carbonitrile' }
 
-sub is_part_of_chain() { return '' }
-
 1;
